@@ -1,4 +1,4 @@
-use crate::types::{Post, Report};
+use crate::types::{Post, Reaction, Report};
 use cosmwasm_std::CustomQuery;
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
@@ -7,6 +7,8 @@ use serde::{Deserialize, Serialize};
 #[serde(rename_all = "snake_case")]
 pub enum DesmosRoute {
     Posts,
+    Subspaces,
+    Profiles,
 }
 
 /// DesmosQueryWrapper is an override of QueryRequest::Custom to access desmos-specific modules
@@ -17,16 +19,17 @@ pub struct DesmosQueryWrapper {
     pub query_data: DesmosQuery,
 }
 
+impl CustomQuery for DesmosQueryWrapper {}
+
 /// DesmosQuery represents the available desmos network queries
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
 pub enum DesmosQuery {
     Posts {},
+    Reactions { post_id: String },
     Reports { post_id: String },
 }
 
-impl CustomQuery for DesmosQueryWrapper {}
-
 /// PostsResponse contains a list of posts
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
@@ -40,3 +43,10 @@ pub struct PostsResponse {
 pub struct ReportsResponse {
     pub reports: Vec<Report>,
 }
+
+/// ReactionsResponse contains the list of reactions associated to the given post_id
+#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
+#[serde(rename_all = "snake_case")]
+pub struct ReactionsResponse {
+    pub reactions: Vec<Reaction>,
+}
